pre.test: pre.test() — Automatic statistical test suggestion

View source: R/pre_Test.R

pre.testR Documentation

pre.test() — Automatic statistical test suggestion

Description

Automatically identifies whether the input data are numeric or categorical and suggests the most appropriate statistical test.

Usage

pre.test(..., alpha = 0.05, help = FALSE, verbose = TRUE)

Arguments

...

Two or more vectors (numeric or categorical), or a data.frame with >= 2 columns

alpha

Significance level. Default = 0.05

help

Logical. If TRUE, shows detailed help

verbose

Logical. If TRUE, prints informative messages

Value

Invisible list with normality results, homogeneity or contingency table, and test recommendation


autotestR documentation built on April 29, 2026, 1:09 a.m.