| pre.test | R Documentation |
Automatically identifies whether the input data are numeric or categorical and suggests the most appropriate statistical test.
pre.test(..., alpha = 0.05, help = FALSE, verbose = TRUE)
... |
Two or more vectors (numeric or categorical), or a data.frame with >= 2 columns |
alpha |
Significance level. Default = 0.05 |
help |
Logical. If TRUE, shows detailed help |
verbose |
Logical. If TRUE, prints informative messages |
Invisible list with normality results, homogeneity or contingency table, and test recommendation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.